@@ -1,23 +1,37 @@
 
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "openbsd2.5"
+#define HOST_OS "openbsd2.9"
 #define HOST_OS_NAME "openbsd2"
-#define HOST_OS_VERSION "2.5"
+#define HOST_OS_VERSION "2.9"
 #define HOST_ARCH "i386"
-#define HOST_NAME "t-rex"
+#define HOST_NAME "a-openbsd29.fsl.cs.sunysb.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Mon Jul  3 18:55:09 EST 2000"
+#define CONFIG_DATE "Sun Dec  9 21:48:35 EST 2001"
 #define PACKAGE "am-utils"
-#define VERSION "6.0.4s6"
+#define VERSION "6.1a5-pre"
 #define PACKAGE "am-utils"
-#define VERSION "6.0.4s6"
+#define VERSION "6.1a5-pre"
 #define DEBUG 1
-#define HOST_HEADER_VERSION "2.5"
+#define STDC_HEADERS 1
+#define HAVE_SYS_TYPES_H 1
+#define HAVE_SYS_STAT_H 1
+#define HAVE_STDLIB_H 1
+#define HAVE_STRING_H 1
+#define HAVE_MEMORY_H 1
+#define HAVE_STRINGS_H 1
+#define HAVE_INTTYPES_H 1
+#define HAVE_UNISTD_H 1
+#define HAVE_DLFCN_H 1
+#define HOST_HEADER_VERSION "2.9"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_ALLOCA 1
-#define STDC_HEADERS 1
+#define HAVE_UNISTD_H 1
+#define HAVE_FORK 1
+#define HAVE_VFORK 1
+#define HAVE_WORKING_VFORK 1
+#define HAVE_WORKING_FORK 1
 #define HAVE_WAIT3 1
 #define HAVE__SETERR_REPLY 1
 #define HAVE_BCMP 1
@@ -32,6 +46,7 @@
 #define HAVE_GETDOMAINNAME 1
 #define HAVE_GETDTABLESIZE 1
 #define HAVE_GETHOSTNAME 1
+#define HAVE_GETIFADDRS 1
 #define HAVE_GETMNTINFO 1
 #define HAVE_GETPAGESIZE 1
 #define HAVE_GETTIMEOFDAY 1
@@ -165,8 +180,10 @@
 #define HAVE_CTYPE_H 1
 #define HAVE_ERRNO_H 1
 #define HAVE_FCNTL_H 1
+#define HAVE_IFADDRS_H 1
 #define HAVE_GRP_H 1
 #define HAVE_LIBGEN_H 1
+#define HAVE_MALLOC_H 1
 #define HAVE_MEMORY_H 1
 #define HAVE_NDBM_H 1
 #define HAVE_NETDB_H 1
@@ -229,8 +246,10 @@
 #define HAVE_EXTERN_USLEEP 1
 #define HAVE_EXTERN_WAIT3 1
 #define HAVE_EXTERN_VSNPRINTF 1
+#define HAVE_EXTERN_XDR_CALLMSG 1
 #define HAVE_EXTERN_XDR_OPAQUE_AUTH 1
 #define HAVE_LONG_FILE_NAMES 1
+#define HAVE_UNISTD_H 1
 #define HAVE_RESTARTABLE_SYSCALLS 1
 #define HAVE_FIELD_CDFS_ARGS_T_FLAGS 1
 #define HAVE_FIELD_CDFS_ARGS_T_FSPEC 1
@@ -247,6 +266,7 @@
 #define HAVE_FIELD_NFS_ARGS_T_SOTYPE 1
 #define HAVE_FIELD_NFS_ARGS_T_VERSION 1
 #define HAVE_FIELD_STRUCT_IFREQ_IFR_ADDR 1
+#define HAVE_FIELD_STRUCT_IFADDRS_IFA_NEXT 1
 #define HAVE_FIELD_STRUCT_SOCKADDR_SA_LEN 1
 #define HAVE_MAP_FILE 1
 #define HAVE_MAP_NDBM 1
@@ -312,12 +332,15 @@
 #define MNT2_NFS_OPT_DEADTHRESH 0x4000
 #define MNT2_NFS_OPT_DUMBTIMR 0x800
 #define MNT2_NFS_OPT_INT 0x40
+#define MNT2_NFS_OPT_KERB 0x400
 #define MNT2_NFS_OPT_LEASETERM 0x1000
 #define MNT2_NFS_OPT_MAXGRPS 0x20
 #define MNT2_NFS_OPT_NFSV3 0x200
 #define MNT2_NFS_OPT_NOCONN 0x80
 #define MNT2_NFS_OPT_NQNFS 0x100
+#define MNT2_NFS_OPT_RDIRPLUS 0x10000
 #define MNT2_NFS_OPT_READAHEAD 0x2000
+#define MNT2_NFS_OPT_READDIRSIZE 0x20000
 #define MNT2_NFS_OPT_RESVPORT 0x0
 #define MNT2_NFS_OPT_RETRANS 0x10
 #define MNT2_NFS_OPT_RSIZE 0x4
