@@ -1,6 +1,10 @@
 #ifndef lint
 /*static char yysccsid[] = "from: @(#)yaccpar	1.9 (Berkeley) 02/21/93";*/
-static const char yyrcsid[] = "$OpenBSD: skeleton.c,v 1.8 1997/01/03 00:53:25 tholo Exp $";
+static char yyrcsid[]
+#if __GNUC__ == 2
+  __attribute__ ((unused))
+#endif /* __GNUC__ == 2 */
+  = "$OpenBSD: skeleton.c,v 1.16 2001/02/26 00:03:33 tholo Exp $";
 #endif
 #include <stdlib.h>
 #define YYBYACC 1
@@ -20,8 +24,24 @@ static const char yyrcsid[] = "$OpenBSD: skeleton.c,v 1.8 1997/01/03 00:53:25 th
 #include <fsi_data.h>
 #include <fsinfo.h>
 
+/* AIX requires this to be the first thing in the file. */
+#ifndef __GNUC__
+# if HAVE_ALLOCA_H
+#  include <alloca.h>
+# else /* not HAVE_ALLOCA_H */
+#  ifdef _AIX
+#pragma alloca
+#  else /* not _AIX */
+#   ifndef alloca
+  /* predefined by HP cc +Olibcalls */
+voidp alloca();
+#   endif /* not alloca */
+#  endif /* not _AIX */
+# endif /* not HAVE_ALLOCA_H */
+#endif /* not __GNUC__ */
+
 extern qelem *list_of_hosts, *list_of_automounts;
-#line 56 "../../fsinfo/fsi_gram.y"
+#line 72 "../../fsinfo/fsi_gram.y"
 typedef union {
 	auto_tree *a;
 	disk_fs *d;
@@ -32,7 +52,7 @@ typedef union {
 	fsi_mount *m;
 	fsmount *f;
 } YYSTYPE;
-#line 36 "y.tab.c"
+#line 56 "y.tab.c"
 #define tARCH 257
 #define tAS 258
 #define tAUTOMOUNT 259
@@ -200,7 +220,12 @@ short yycheck[] = {                                      61,
 #endif
 #define YYMAXTOKEN 284
 #if YYDEBUG
-char *yyname[] = {
+#if defined(__cplusplus) || __STDC__
+const char * const yyname[] =
+#else
+char *yyname[] =
+#endif
+	{
 "end-of-file",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,"'='",0,0,0,0,0,0,0,0,0,0,
 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
@@ -213,8 +238,12 @@ char *yyname[] = {
 "tMOUNT","tNETMASK","tNETIF","tVOLNAME","tOPTS","tOS","tPASSNO","tDIRECT",
 "tSEL","tSTR",
 };
-char *yyrule[] = {
-"$accept : list_of_hosts",
+#if defined(__cplusplus) || __STDC__
+const char * const yyrule[] =
+#else
+char *yyrule[] =
+#endif
+	{"$accept : list_of_hosts",
 "list_of_hosts :",
 "list_of_hosts : list_of_hosts host",
 "list_of_hosts : list_of_hosts automount",
@@ -315,17 +344,30 @@ static int yygrowstack()
     else if ((newsize *= 2) > YYMAXDEPTH)
         newsize = YYMAXDEPTH;
     i = yyssp - yyss;
-    if ((newss = (short *)realloc(yyss, newsize * sizeof *newss)) == NULL)
-        return -1;
+    newss = yyss ? (short *)realloc(yyss, newsize * sizeof *newss) :
+      (short *)malloc(newsize * sizeof *newss);
+    if (newss == NULL)
+        goto bail;
     yyss = newss;
     yyssp = newss + i;
-    if ((newvs = (YYSTYPE *)realloc(yyvs, newsize * sizeof *newvs)) == NULL)
-        return -1;
+    newvs = yyvs ? (YYSTYPE *)realloc(yyvs, newsize * sizeof *newvs) :
+      (YYSTYPE *)malloc(newsize * sizeof *newvs);
+    if (newvs == NULL)
+        goto bail;
     yyvs = newvs;
     yyvsp = newvs + i;
     yystacksize = newsize;
     yysslim = yyss + newsize - 1;
     return 0;
+bail:
+    if (yyss)
+            free(yyss);
+    if (yyvs)
+            free(yyvs);
+    yyss = yyssp = NULL;
+    yyvs = yyvsp = NULL;
+    yystacksize = 0;
+    return -1;
 }
 
 #define YYABORT goto yyabort
@@ -341,7 +383,11 @@ yyparse()
 {
     register int yym, yyn, yystate;
 #if YYDEBUG
+#if defined(__cplusplus) || __STDC__
+    register const char *yys;
+#else /* !(defined(__cplusplus) || __STDC__) */
     register char *yys;
+#endif /* !(defined(__cplusplus) || __STDC__) */
 
     if ((yys = getenv("YYDEBUG")))
     {
@@ -349,7 +395,7 @@ yyparse()
         if (yyn >= '0' && yyn <= '9')
             yydebug = yyn - '0';
     }
-#endif
+#endif /* YYDEBUG */
 
     yynerrs = 0;
     yyerrflag = 0;
@@ -473,84 +519,84 @@ yyreduce:
     switch (yyn)
     {
 case 1:
-#line 112 "../../fsinfo/fsi_gram.y"
+#line 128 "../../fsinfo/fsi_gram.y"
 { yyval.q = new_que(); }
 break;
 case 2:
-#line 115 "../../fsinfo/fsi_gram.y"
+#line 131 "../../fsinfo/fsi_gram.y"
 { if (yyvsp[0].h) ins_que((qelem *) yyvsp[0].h, list_of_hosts->q_back);
 	    yyval.q = yyvsp[-1].q; }
 break;
 case 3:
-#line 119 "../../fsinfo/fsi_gram.y"
+#line 135 "../../fsinfo/fsi_gram.y"
 { if (yyvsp[0].a) ins_que((qelem *) yyvsp[0].a, list_of_automounts->q_back);
 	    yyval.q = yyvsp[-1].q; }
 break;
 case 4:
-#line 130 "../../fsinfo/fsi_gram.y"
+#line 146 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-2].h; yyval.h->h_disk_fs = yyvsp[-1].q; yyval.h->h_mount = yyvsp[0].q; }
 break;
 case 5:
-#line 133 "../../fsinfo/fsi_gram.y"
+#line 149 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-2].h; yyval.h->h_disk_fs = yyvsp[-1].q; yyval.h->h_mount = yyvsp[0].q; }
 break;
 case 6:
-#line 139 "../../fsinfo/fsi_gram.y"
+#line 155 "../../fsinfo/fsi_gram.y"
 { yyval.h = new_host(); set_host(yyval.h, HF_HOST, yyvsp[0].s); }
 break;
 case 7:
-#line 142 "../../fsinfo/fsi_gram.y"
+#line 158 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-2].h; set_host(yyval.h, HF_HOST, yyvsp[0].s); }
 break;
 case 8:
-#line 148 "../../fsinfo/fsi_gram.y"
+#line 164 "../../fsinfo/fsi_gram.y"
 { yyval.h = new_host(); }
 break;
 case 9:
-#line 151 "../../fsinfo/fsi_gram.y"
+#line 167 "../../fsinfo/fsi_gram.y"
 { if (yyvsp[-1].e) {
 		yyvsp[-1].e->e_if = yyvsp[-3].s;
 		yyval.h = yyvsp[-5].h; set_host(yyval.h, HF_ETHER, (char *) yyvsp[-1].e); }
 	  }
 break;
 case 10:
-#line 157 "../../fsinfo/fsi_gram.y"
+#line 173 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-2].h; set_host(yyval.h, HF_CONFIG, yyvsp[0].s); }
 break;
 case 11:
-#line 160 "../../fsinfo/fsi_gram.y"
+#line 176 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-3].h; set_host(yyval.h, HF_ARCH, yyvsp[0].s); }
 break;
 case 12:
-#line 163 "../../fsinfo/fsi_gram.y"
+#line 179 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-3].h; set_host(yyval.h, HF_OS, yyvsp[0].s); }
 break;
 case 13:
-#line 166 "../../fsinfo/fsi_gram.y"
+#line 182 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-3].h; set_host(yyval.h, HF_CLUSTER, yyvsp[0].s); }
 break;
 case 14:
-#line 169 "../../fsinfo/fsi_gram.y"
+#line 185 "../../fsinfo/fsi_gram.y"
 { yyerror("unknown host attribute"); }
 break;
 case 15:
-#line 174 "../../fsinfo/fsi_gram.y"
+#line 190 "../../fsinfo/fsi_gram.y"
 { yyval.e = new_ether_if(); }
 break;
 case 16:
-#line 177 "../../fsinfo/fsi_gram.y"
+#line 193 "../../fsinfo/fsi_gram.y"
 { yyval.e = yyvsp[-3].e; set_ether_if(yyval.e, EF_INADDR, yyvsp[0].s); }
 break;
 case 17:
-#line 179 "../../fsinfo/fsi_gram.y"
+#line 195 "../../fsinfo/fsi_gram.y"
 { yyval.e = yyvsp[-3].e; set_ether_if(yyval.e, EF_NETMASK, yyvsp[0].s); }
 break;
 case 18:
-#line 181 "../../fsinfo/fsi_gram.y"
+#line 197 "../../fsinfo/fsi_gram.y"
 { yyval.e = yyvsp[-3].e; set_ether_if(yyval.e, EF_HWADDR, yyvsp[0].s); }
 break;
 case 19:
-#line 191 "../../fsinfo/fsi_gram.y"
+#line 207 "../../fsinfo/fsi_gram.y"
 { if (yyvsp[0].q) {
 		yyval.a = new_auto_tree(yyvsp[-1].s, yyvsp[0].q);
 	    } else {
@@ -559,23 +605,23 @@ case 19:
 	  }
 break;
 case 20:
-#line 199 "../../fsinfo/fsi_gram.y"
+#line 215 "../../fsinfo/fsi_gram.y"
 { yyval.a = 0; }
 break;
 case 21:
-#line 204 "../../fsinfo/fsi_gram.y"
+#line 220 "../../fsinfo/fsi_gram.y"
 { yyval.s = strdup(""); }
 break;
 case 22:
-#line 207 "../../fsinfo/fsi_gram.y"
+#line 223 "../../fsinfo/fsi_gram.y"
 { yyval.s = yyvsp[0].s; }
 break;
 case 23:
-#line 212 "../../fsinfo/fsi_gram.y"
+#line 228 "../../fsinfo/fsi_gram.y"
 { yyval.q = 0; }
 break;
 case 24:
-#line 215 "../../fsinfo/fsi_gram.y"
+#line 231 "../../fsinfo/fsi_gram.y"
 { if (yyvsp[0].d) {
 		if (yyvsp[-1].q)
 			yyval.q = yyvsp[-1].q;
@@ -588,55 +634,55 @@ case 24:
 	  }
 break;
 case 25:
-#line 234 "../../fsinfo/fsi_gram.y"
+#line 250 "../../fsinfo/fsi_gram.y"
 { yyvsp[-1].d->d_dev = yyvsp[-3].s; yyval.d = yyvsp[-1].d; }
 break;
 case 26:
-#line 237 "../../fsinfo/fsi_gram.y"
+#line 253 "../../fsinfo/fsi_gram.y"
 { yyval.d = (disk_fs *) 0; }
 break;
 case 27:
-#line 253 "../../fsinfo/fsi_gram.y"
+#line 269 "../../fsinfo/fsi_gram.y"
 { yyval.d = new_disk_fs(); }
 break;
 case 28:
-#line 256 "../../fsinfo/fsi_gram.y"
+#line 272 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_FSTYPE, yyvsp[0].s); }
 break;
 case 29:
-#line 259 "../../fsinfo/fsi_gram.y"
+#line 275 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_OPTS, yyvsp[0].s); }
 break;
 case 30:
-#line 262 "../../fsinfo/fsi_gram.y"
+#line 278 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_PASSNO, yyvsp[0].s); }
 break;
 case 31:
-#line 265 "../../fsinfo/fsi_gram.y"
+#line 281 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_FREQ, yyvsp[0].s); }
 break;
 case 32:
-#line 268 "../../fsinfo/fsi_gram.y"
+#line 284 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-2].d; set_disk_fs(yyval.d, DF_MOUNT, (char *) yyvsp[0].q); }
 break;
 case 33:
-#line 271 "../../fsinfo/fsi_gram.y"
+#line 287 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_DUMPSET, yyvsp[0].s); }
 break;
 case 34:
-#line 274 "../../fsinfo/fsi_gram.y"
+#line 290 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_LOG, yyvsp[0].s); }
 break;
 case 35:
-#line 277 "../../fsinfo/fsi_gram.y"
+#line 293 "../../fsinfo/fsi_gram.y"
 { yyerror("unknown filesystem attribute"); }
 break;
 case 36:
-#line 291 "../../fsinfo/fsi_gram.y"
+#line 307 "../../fsinfo/fsi_gram.y"
 { yyval.q = 0; }
 break;
 case 37:
-#line 294 "../../fsinfo/fsi_gram.y"
+#line 310 "../../fsinfo/fsi_gram.y"
 { automount *a = new_automount(yyvsp[-3].s);
 	    a->a_volname = yyvsp[0].s;
 	    a->a_opts = yyvsp[-2].s;
@@ -648,7 +694,7 @@ case 37:
 	  }
 break;
 case 38:
-#line 304 "../../fsinfo/fsi_gram.y"
+#line 320 "../../fsinfo/fsi_gram.y"
 { automount *a = new_automount(yyvsp[-3].s);
             a->a_hardwiredfs = yyvsp[0].s;
             a->a_opts = yyvsp[-2].s;
@@ -660,7 +706,7 @@ case 38:
           }
 break;
 case 39:
-#line 315 "../../fsinfo/fsi_gram.y"
+#line 331 "../../fsinfo/fsi_gram.y"
 { automount *a = new_automount(yyvsp[-2].s);
 	    a->a_symlink = yyvsp[0].s;
 	    if (yyvsp[-3].q)
@@ -671,7 +717,7 @@ case 39:
 	  }
 break;
 case 40:
-#line 325 "../../fsinfo/fsi_gram.y"
+#line 341 "../../fsinfo/fsi_gram.y"
 { automount *a = new_automount(yyvsp[-4].s);
 	    a->a_mount = yyvsp[-1].q;
 	    a->a_opts = yyvsp[-3].s;
@@ -683,11 +729,11 @@ case 40:
 	  }
 break;
 case 41:
-#line 338 "../../fsinfo/fsi_gram.y"
+#line 354 "../../fsinfo/fsi_gram.y"
 { yyval.q = 0; }
 break;
 case 42:
-#line 341 "../../fsinfo/fsi_gram.y"
+#line 357 "../../fsinfo/fsi_gram.y"
 { yyvsp[-2].m->m_mount = yyvsp[-1].q;
 	    yyvsp[-2].m->m_name = yyvsp[-4].s;
 	    if (yyvsp[-4].s[0] != '/' && yyvsp[-4].s[1] && strchr(yyvsp[-4].s+1, '/'))
@@ -700,31 +746,31 @@ case 42:
 	  }
 break;
 case 43:
-#line 355 "../../fsinfo/fsi_gram.y"
+#line 371 "../../fsinfo/fsi_gram.y"
 { yyval.m = new_mount(); }
 break;
 case 44:
-#line 358 "../../fsinfo/fsi_gram.y"
+#line 374 "../../fsinfo/fsi_gram.y"
 { yyval.m = yyvsp[-2].m; set_mount(yyval.m, DM_EXPORTFS, yyvsp[0].s); }
 break;
 case 45:
-#line 361 "../../fsinfo/fsi_gram.y"
+#line 377 "../../fsinfo/fsi_gram.y"
 { yyval.m = yyvsp[-2].m; set_mount(yyval.m, DM_VOLNAME, yyvsp[0].s); }
 break;
 case 46:
-#line 364 "../../fsinfo/fsi_gram.y"
+#line 380 "../../fsinfo/fsi_gram.y"
 { yyval.m = yyvsp[-2].m; set_mount(yyval.m, DM_SEL, yyvsp[0].s); }
 break;
 case 47:
-#line 367 "../../fsinfo/fsi_gram.y"
+#line 383 "../../fsinfo/fsi_gram.y"
 { yyerror("unknown directory attribute"); }
 break;
 case 48:
-#line 377 "../../fsinfo/fsi_gram.y"
+#line 393 "../../fsinfo/fsi_gram.y"
 { yyval.q = 0; }
 break;
 case 49:
-#line 380 "../../fsinfo/fsi_gram.y"
+#line 396 "../../fsinfo/fsi_gram.y"
 { set_fsmount(yyvsp[0].f, FM_VOLNAME, yyvsp[-1].s);
 	    if (yyvsp[-3].q)
 		yyval.q = yyvsp[-3].q;
@@ -734,34 +780,34 @@ case 49:
 	    }
 break;
 case 50:
-#line 400 "../../fsinfo/fsi_gram.y"
+#line 416 "../../fsinfo/fsi_gram.y"
 { yyval.f = new_fsmount(); }
 break;
 case 51:
-#line 403 "../../fsinfo/fsi_gram.y"
+#line 419 "../../fsinfo/fsi_gram.y"
 { yyval.f = yyvsp[-1].f; set_fsmount(yyval.f, FM_DIRECT, ""); }
 break;
 case 52:
-#line 406 "../../fsinfo/fsi_gram.y"
+#line 422 "../../fsinfo/fsi_gram.y"
 { yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_LOCALNAME, yyvsp[0].s); }
 break;
 case 53:
-#line 409 "../../fsinfo/fsi_gram.y"
+#line 425 "../../fsinfo/fsi_gram.y"
 { yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_FROM, yyvsp[0].s); }
 break;
 case 54:
-#line 412 "../../fsinfo/fsi_gram.y"
+#line 428 "../../fsinfo/fsi_gram.y"
 { yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_FSTYPE, yyvsp[0].s); }
 break;
 case 55:
-#line 415 "../../fsinfo/fsi_gram.y"
+#line 431 "../../fsinfo/fsi_gram.y"
 { yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_OPTS, yyvsp[0].s); }
 break;
 case 56:
-#line 418 "../../fsinfo/fsi_gram.y"
+#line 434 "../../fsinfo/fsi_gram.y"
 { yyerror("unknown mount attribute"); }
 break;
-#line 765 "y.tab.c"
+#line 802 "y.tab.c"
     }
     yyssp -= yym;
     yystate = *yyssp;
